"""DeepVisionGuru utilities"""

# Version of the dvgutils package
__version__ = "0.1.2"

from .logger import setup_logger
from .config import load_config, overwrite_config
from .colors import colors
